@@ -197,7 +197,8 @@ def create_application(allow_origins) -> FastAPI:
     app = FastAPI(
         title="ImJoy Core Server",
         description=(
-            "A server for managing imjoy plugins and enabling remote procedure calls"
+            "A server for managing imjoy plugins and \
+                enabling remote procedure calls"
         ),
         version=VERSION,
     )
@@ -251,6 +252,11 @@ def start_server(args):
         allow_origin = env.get("ALLOW_ORIGINS", "*").split(",")
     application = create_application(allow_origin)
     setup_socketio_server(application, allow_origins=allow_origin)
+    if args.host == "127.0.0.1" or args.host == "localhost":
+        print(
+            "***Note: If you want to enable access from another host,\
+                 please start with `--host=0.0.0.0`.***"
+        )
     uvicorn.run(application, host=args.host, port=int(args.port))
 
 
